@@ -114,7 +114,7 @@
 #' @importFrom shinyjs useShinyjs hidden show
 #' @importFrom shinythemes shinytheme
 #' @importFrom miniUI gadgetTitleBar
-#' @importFrom shinyBS bsButton updateButton
+#' @importFrom shinyBS bsButton updateButton addTooltip
 #' @importFrom rhandsontable %>%
 #'
 #' @author Dillon Hammill, \email{Dillon.Hammill@anu.edu.au}
@@ -238,13 +238,10 @@ data_edit <- function(x = NULL,
         style = "padding-left: 5px; margin-top: 35px;",
         dataSelectUI("select1"),
         dataFilterUI("filter1"),
-        hidden(
-          actionButton("sync", 
-                       label = NULL, 
-                       icon = icon("sync"))
-        ),
+        dataSyncUI("sync1"),
         dataOutputUI("output-active"),
-        dataOutputUI("output-update", icon = "file-download"),
+        dataOutputUI("output-update", 
+                     icon = "file-download"),
         hidden(
           bsButton("cut",
                    label = NULL,
@@ -271,7 +268,13 @@ data_edit <- function(x = NULL,
     # SHOW BUTTONS
     if(!hide) {
       show("sync")
+      addTooltip(session = session,
+                 id = "sync",
+                 title = "sychronise")
       show("cut")
+      addTooltip(session = session,
+                 id = "cut",
+                 title = "crop to selection")
     }
     
     # DATA STORAGE
@@ -305,12 +308,14 @@ data_edit <- function(x = NULL,
     # DATA SELECT
     data_select <- dataSelectServer("select1",
                                     data = reactive(values$data),
-                                    hide = hide)
+                                    hide = hide,
+                                    hover_text = "select columns")
     
     # DATA FILTER
     data_filter <- dataFilterServer("filter1",
                                     data = reactive(values$data),
-                                    hide = hide)
+                                    hide = hide,
+                                    hover_text = "filter rows")
     
     # UPDATE FILTERS
     observe({
@@ -364,36 +369,15 @@ data_edit <- function(x = NULL,
     })
     
     # SYNC
-    observeEvent(input$sync, {
-      # ENTIRE DATA
-      if(length(values$rows) == 0 & length(values$columns) == 0) {
-        values$data <- values$data_active
-      # DATA
-      } else {
-        # VALUES
-        if(length(values$rows) != 0 & length(values$columns) == 0) {
-          values$data[values$rows, ] <- values$data_active
-        } else if(length(values$rows) == 0 & length(values$columns) != 0) {
-          values$data[ , values$columns] <- values$data_active
-        } else if(length(values$rows) != 0 & length(values$columns) != 0) {
-          values$data[values$rows, values$columns] <- values$data_active
-        }
-        # ROW/COLUMN NAMES
-        if(!is.null(values$data_active)) {
-          # ROW NAMES
-          if(!all(rownames(values$data_active) == 
-                  rownames(values$data)[values$rows])) {
-            rownames(values$data)[values$rows] <- 
-              rownames(values$data_active)
-          }
-          # COLUMN NAMES
-          if(!all(colnames(values$data_active) == 
-                  colnames(values$data)[values$columns])) {
-            colnames(values$data)[values$columns] <- 
-              colnames(values$data_active)
-          }
-        }
-      }
+    data_sync <- dataSyncServer("sync1",
+                                data = reactive(values$data),
+                                data_subset = reactive(values$data_active),
+                                rows = reactive(values$rows),
+                                columns = reactive(values$cols),
+                                hide = hide,
+                                hover_text = "synchronise")
+    observe({
+      values$data <- data_sync()
     })
     
     # DATA OUTPUT - DATA ACTIVE
@@ -402,7 +386,8 @@ data_edit <- function(x = NULL,
                      save_as = save_as,
                      write_fun = write_fun,
                      write_args = write_args,
-                     hide = hide)
+                     hide = hide,
+                     hover_text = "save selection \n to file")
     
     # DATA OUTPUT - DATA ENTIRE
     dataOutputServer("output-update",
@@ -410,7 +395,8 @@ data_edit <- function(x = NULL,
                      save_as = save_as,
                      write_fun = write_fun,
                      write_args = write_args,
-                     hide = hide)
+                     hide = hide,
+                     hover_text = "save to file")
     
     # CUT
     observeEvent(input$cut, {
@@ -483,6 +469,8 @@ data_edit <- function(x = NULL,
                       viewer = viewer,
                       stopOnCancel = FALSE)
   
+  # x_edit <- shiny::shinyApp(ui, server)
+  
   # SAVE AS
   if(!is.null(x_edit) & !is.null(save_as)) {
     do.call(
